nose: Python unit testing framework
===================================

Description
-----------

nose extends the test loading and running features of unittest, making
it easier to write, find and run tests.

License
-------

GNU LGPL


Upstream Contact
----------------

Author: Jason Pellerin Home Page: http://readthedocs.org/docs/nose/

   see also https://github.com/nose-devs/nose

Dependencies
------------

-  setuptools / distribute
-  Python
-  GNU patch (shipped with Sage)


Special Update/Build Instructions
---------------------------------

None.
